@@ -25,13 +25,21 @@ treedata<-function(phy, data, data.names=NULL, sort=F)
 	}
 	nc<-name.check(phy, data, data.names)
 	if(is.na(nc[[1]][1]) | nc[[1]][1]!="OK") {
-		if(length(nc[[1]]!=0))
+		if(length(nc[[1]]!=0)) {
 			phy=drop.tip(phy, nc[[1]])
+			cat("Dropped tips from the tree because there were no matching names in the data:\n")
+			print(nc[[1]])
+			cat("\n")
+		}
 	
 		if(length(nc[[2]]!=0)) {
 			m<-match(data.names, nc[[2]])
 			data=as.matrix(data[is.na(m),])
 			data.names<-data.names[is.na(m)]
+			cat("Dropped rows from the data because there were no matching tips in the tree:\n")
+			print(nc[[2]])
+			cat("\n")
+
 			}
  	}
 	order<-match(data.names, phy$tip.label)	
